pygeodesy.geodsolve._GeodesicSolveBase

Package pygeodesy :: Module geodsolve :: Class _GeodesicSolveBase |
[frames] | no frames]

# Class _GeodesicSolveBase

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
        karney._CapsBase --+
                           |
    solveBase._SolveCapsBase --+
                               |
            solveBase._SolveBase --+
                                   |
               solveBase._Solve3Base --+
                                       |
               solveBase._SolveGDictBase --+
                                           |
                                          _GeodesicSolveBase

Known Subclasses:
  - GeodesicLineSolve
  - , GeodesicSolve

(INTERNAL) Base class for GeodesicSolve and GeodesicLineSolve.

Instance Methods
Inherited from `solveBase._SolveGDictBase`: `ArcDirect`, `Direct`, `Inverse`, `Inverse1`, `__init__`, `toStr` Inherited from `solveBase._SolveCapsBase`: `invokat`, `invoke`, `linelimit` Inherited from `karney._CapsBase`: `caps_` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables
Inherited from `karney._CapsBase`: `ALL`, `AREA`, `AZIMUTH`, `DISTANCE`, `DISTANCE_IN`, `EMPTY`, `GEODESICSCALE`, `LATITUDE`, `LINE_CAPS`, `LINE_OFF`, `LONGITUDE`, `LONG_UNROLL`, `NONFINITONAN`, `REDUCEDLENGTH`, `STANDARD`, `STANDARD_LINE`

Properties
| GeodSolve Get the GeodSolve executable (`filename`).
Inherited from `solveBase._SolveBase`: `reverse2`, `unroll` Inherited from `solveBase._SolveCapsBase`: `Exact`, `a`, `b`, `datum`, `ellipsoid`, `f`, `flattening`, `invokation`, `prec`, `status`, `verbose`, `version` Inherited from `karney._CapsBase`: `caps`, `debug` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Property Details

### GeodSolve Get the GeodSolve executable (`filename`). Get method: GeodSolve(self) - Get the GeodSolve executable (`filename`). Set method: GeodSolve(self, path) - Set the GeodSolve executable (`filename`), the (fully qualified) path to the `GeodSolve` executable. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.